@@ -37,11 +37,13 @@ import os
 from docopt import docopt
 from cloud_builder.version import __version__
 from cloud_builder.cloud_logger import CBCloudLogger
+from cloud_builder.identity import CBIdentity
 from cloud_builder.exceptions import exception_handler
 from cloud_builder.defaults import Defaults
-from cloud_builder.package_request import CBPackageRequest
-from cloud_builder.message_broker import CBMessageBroker
-from cloud_builder.response import CBResponse
+from cloud_builder.package_metadata.package_metadata import CBPackageMetaData
+from cloud_builder.package_request.package_request import CBPackageRequest
+from cloud_builder.broker import CBMessageBroker
+from cloud_builder.response.response import CBResponse
 from kiwi.command import Command
 from apscheduler.schedulers.background import BlockingScheduler
 from kiwi.privileges import Privileges
@@ -131,8 +133,8 @@ def update_project() -> None:
     )
     for package_source_path in sorted(changed_packages.keys()):
         log = CBCloudLogger('CBFetch', os.path.basename(package_source_path))
-        package_config = Defaults.get_package_config(
-            package_source_path
+        package_config = CBPackageMetaData.get_package_config(
+            package_source_path, log, CBIdentity.get_request_id()
         )
         if package_config:
             for target in package_config.get('distributions') or []:
@@ -152,4 +154,4 @@ def update_project() -> None:
                     package=request['package'],
                     arch=request['arch']
                 )
-                log.response(response.get_data())
+                log.response(response, broker)
