@@ -32,11 +32,12 @@ import os
 from docopt import docopt
 from cloud_builder.version import __version__
 from cloud_builder.exceptions import exception_handler
+from cloud_builder.broker import CBMessageBroker
 from cloud_builder.defaults import Defaults
 from kiwi.privileges import Privileges
 from kiwi.command import Command
 from cloud_builder.cloud_logger import CBCloudLogger
-from cloud_builder.response import CBResponse
+from cloud_builder.response.response import CBResponse
 
 
 @exception_handler
@@ -71,12 +72,20 @@ def main() -> None:
 
     package_name = args.get('--root').replace(
         Defaults.get_runner_package_root(), ''
-    ).split('@')[0]
+    ).split('@')[0].strip(os.sep)
 
     log = CBCloudLogger('CBRun', package_name)
 
-    build_log_file = os.path.join(
-        args['--root'], '.build.log'
+    # created by run.sh script written in cb_prepare and called here
+    build_log_file = ''.join(
+        [args['--root'].rstrip(os.sep), '.build.log']
+    )
+    # created by kiwi resolve-package-list called in cb_prepare
+    solver_json_file = ''.join(
+        [args['--root'].rstrip(os.sep), '.solver.json']
+    )
+    build_result_file = ''.join(
+        [args['--root'].rstrip(os.sep), '.result.yml']
     )
     log.info(
         f'Starting package build. For details see: {build_log_file}'
@@ -112,7 +121,13 @@ def main() -> None:
         response_code=status,
         package=package_name,
         log_file=build_log_file,
+        solver_file=solver_json_file,
         binary_packages=packages,
         exit_code=exit_code
     )
-    log.response(response.get_data())
+    broker = CBMessageBroker.new(
+        'kafka', config_file=Defaults.get_kafka_config()
+    )
+    log.response(
+        response, broker, build_result_file
+    )
