@@ -43,9 +43,10 @@ from docopt import docopt
 from textwrap import dedent
 from cloud_builder.version import __version__
 from cloud_builder.cloud_logger import CBCloudLogger
-from cloud_builder.response import CBResponse
+from cloud_builder.response.response import CBResponse
 from cloud_builder.defaults import Defaults
-from cloud_builder.message_broker import CBMessageBroker
+from cloud_builder.package_metadata.package_metadata import CBPackageMetaData
+from cloud_builder.broker import CBMessageBroker
 from kiwi.command import Command
 from kiwi.privileges import Privileges
 from kiwi.path import Path
@@ -149,6 +150,10 @@ def handle_build_requests(poll_timeout: int, running_limit: int) -> None:
     """
     Check on the runner state and if ok listen to the
     message broker queue for new package build requests
+    The package_request_queue is used as shared queue
+    within a single group. It's important to have this
+    queue configured to distribute messages across
+    several readers to let multiple CB scheduler scale
 
     :param int poll_timeout:
         timeout in msec after which the blocking read() to the
@@ -180,41 +185,43 @@ def handle_build_requests(poll_timeout: int, running_limit: int) -> None:
                 timeout_ms=poll_timeout
             ):
                 request = broker.validate_package_request(message.value)
-                status_flags = Defaults.get_status_flags()
-                response = CBResponse(request['request_id'], log.get_id())
-                if request['arch'] == platform.machine():
-                    response.set_package_build_scheduled_response(
-                        message='Accept package build request',
-                        response_code=status_flags.package_request_accepted,
-                        package=request['package'],
-                        arch=request['arch']
-                    )
-                    broker.acknowledge()
-                    log.response(response.get_data())
-                    build_package(request)
-                else:
-                    # do not acknowledge/build if the host architecture
-                    # does not match the package. The request stays in
-                    # the topic to be presented for other schedulers
-                    response.set_buildhost_arch_incompatible_response(
-                        message=f'Incompatible arch: {platform.machine()}',
-                        response_code=status_flags.package_request_accepted,
-                        package=request['package'],
-                        arch=request['arch']
-                    )
-                    log.response(response.get_data())
+                if request:
+                    status_flags = Defaults.get_status_flags()
+                    response = CBResponse(request['request_id'], log.get_id())
+                    if request['arch'] == platform.machine():
+                        response.set_package_build_scheduled_response(
+                            message='Accept package build request',
+                            response_code=status_flags.package_request_accepted,
+                            package=request['package'],
+                            arch=request['arch']
+                        )
+                        broker.acknowledge()
+                        log.response(response, broker)
+                        build_package(request, broker)
+                    else:
+                        # do not acknowledge/build if the host architecture
+                        # does not match the package. The request stays in
+                        # the topic to be presented for other schedulers
+                        response.set_buildhost_arch_incompatible_response(
+                            message=f'Incompatible arch: {platform.machine()}',
+                            response_code=status_flags.package_request_accepted,
+                            package=request['package'],
+                            arch=request['arch']
+                        )
+                        log.response(response, broker)
     finally:
         log.info('Closing message broker connection')
         broker.close()
 
 
-def build_package(request: Dict) -> None:
+def build_package(request: Dict, broker: CBMessageBroker) -> None:
     """
     Update the package sources and run the script which
     utilizes cb-prepare/cb-run to build the package for
     all configured targets
 
     :param dict request: yaml dict request record
+    :param CBMessageBroker broker: instance of CBMessageBroker
     """
     log = CBCloudLogger(
         'CBScheduler', os.path.basename(request['package'])
@@ -222,31 +229,33 @@ def build_package(request: Dict) -> None:
     package_source_path = os.path.join(
         Defaults.get_runner_project_dir(), format(request['package'])
     )
-    if check_package_sources(package_source_path, request, log):
-        package_config = Defaults.get_package_config(
-            package_source_path
+    if check_package_sources(package_source_path, request, log, broker):
+        package_config = CBPackageMetaData.get_package_config(
+            package_source_path, log, request['request_id']
         )
-        reset_build_if_running(package_config, request, log)
+        if package_config:
+            reset_build_if_running(package_config, request, log, broker)
 
-        status_flags = Defaults.get_status_flags()
-        if request['action'] == status_flags.package_changed:
-            log.info('Update project git source repo prior build')
-            Command.run(
-                ['git', '-C', Defaults.get_runner_project_dir(), 'pull']
-            )
-
-        log.info('Starting build process')
-        Command.run(
-            [
-                'bash', create_run_script(
-                    package_config, request, package_source_path
+            status_flags = Defaults.get_status_flags()
+            if request['action'] == status_flags.package_changed:
+                log.info('Update project git source repo prior build')
+                Command.run(
+                    ['git', '-C', Defaults.get_runner_project_dir(), 'pull']
                 )
-            ]
-        )
+
+            log.info('Starting build process')
+            Command.run(
+                [
+                    'bash', create_run_script(
+                        package_config, request, package_source_path
+                    )
+                ]
+            )
 
 
 def reset_build_if_running(
-    package_config: Dict, request: Dict, log: CBCloudLogger
+    package_config: Dict, request: Dict, log: CBCloudLogger,
+    broker: CBMessageBroker
 ) -> None:
     """
     Check if the same package/arch is currently/still running
@@ -255,6 +264,7 @@ def reset_build_if_running(
     :param dict package_config: yaml dict from cloud_builder.yml
     :param dict request: yaml dict request record
     :param CBCloudLogger log: logger instance
+    :param CBMessageBroker broker: instance of CBMessageBroker
     """
     package_root = os.path.join(
         Defaults.get_runner_package_root(), package_config['name']
@@ -279,7 +289,7 @@ def reset_build_if_running(
                 package=request['package'],
                 arch=request['arch']
             )
-            log.response(response.get_data())
+            log.response(response, broker)
             os.kill(build_pid, signal.SIGTERM)
 
 
@@ -296,7 +306,8 @@ def get_running_builds() -> int:
 
 
 def check_package_sources(
-    package_source_path: str, request: Dict, log: CBCloudLogger
+    package_source_path: str, request: Dict, log: CBCloudLogger,
+    broker: CBMessageBroker
 ) -> bool:
     """
     Sanity checks on the given package sources
@@ -308,6 +319,7 @@ def check_package_sources(
     :param str package_source_path: path to package sources
     :param dict request: yaml dict request record
     :param CBCloudLogger log: logger instance
+    :param CBMessageBroker broker: instance of CBMessageBroker
     """
     if not os.path.isdir(package_source_path):
         status_flags = Defaults.get_status_flags()
@@ -318,7 +330,7 @@ def check_package_sources(
             package=request['package'],
             arch=request['arch']
         )
-        log.response(response.get_data())
+        log.response(response, broker)
         return False
 
     # TODO: Also check for meta data files (.kiwi and cloud_builder.yml)
@@ -348,13 +360,17 @@ def create_run_script(
 
         set -e
 
-        function finish {
-            kill $(jobs -p) &>/dev/null
-        }
+        rm -f {package_root}.log
 
-        {
+        function finish {{
+            kill $(jobs -p) &>/dev/null
+        }}
+
+        {{
         trap finish EXIT
-    ''')
+    ''').format(
+        package_root=package_root
+    )
     for target in package_config.get('distributions') or []:
         if target['arch'] == platform.machine():
             dist_profile = f'{target["dist"]}.{target["arch"]}'
@@ -363,7 +379,7 @@ def create_run_script(
                     --package {package_source_path} \\
                     --profile {dist_profile} \\
                     --request-id {request_id}
-                cb-run --root {target_root} &> {target_root}.log \\
+                cb-run --root {target_root} &> {target_root}.build.log \\
                     --request-id {request_id}
             ''').format(
                 runner_root=Defaults.get_runner_package_root(),
@@ -373,7 +389,7 @@ def create_run_script(
                 request_id=request['request_id']
             )
     run_script += dedent('''
-        }} &>{package_root}.log &
+        }} &>>{package_root}.log &
 
         echo $! > {package_root}.pid
     ''').format(
