@@ -16,23 +16,22 @@
 # along with Cloud Builder.  If not, see <http://www.gnu.org/licenses/>
 #
 import os
-import yaml
-from typing import (
-    Dict, NamedTuple
-)
+from typing import NamedTuple
 
 status_flags = NamedTuple(
     'status_flags', [
         ('package_changed', str),
         ('package_build_failed', str),
         ('package_build_succeeded', str),
+        ('package_build_running', str),
         ('buildroot_setup_failed', str),
         ('buildroot_setup_succeeded', str),
         ('package_update_request', str),
         ('package_request_accepted', str),
         ('incompatible_build_arch', str),
         ('reset_running_build', str),
-        ('package_not_existing', str)
+        ('package_not_existing', str),
+        ('invalid_metadata', str)
     ]
 )
 
@@ -44,19 +43,51 @@ class Defaults:
     @staticmethod
     def get_package_request_queue_name() -> str:
         """
-        Return name of message queue for sending sending
-        package build requests
+        Return name of message queue used for sending
+        package build requests.
+
+        Queue is a shared queue:
+        Each reader compete with each other and for each message,
+        only one reader will get it. It's important to configure
+        the queue in a way that it distributes requests across
+        readers. In kafka this done by assigning as many partitions
+        as there are potential readers
         """
-        return 'cb-request'
+        return 'cb-package-request'
 
     @staticmethod
     def get_response_queue_name() -> str:
         """
-        Return name of message queue for sending cloud
-        builder response messages
+        Return name of message queue used for sending
+        response messages of the Cloud Builder system
+
+        Queue is a publish/subscribe queue:
+        Each message is broadcast to all readers.
         """
         return 'cb-response'
 
+    @staticmethod
+    def get_info_request_queue_name() -> str:
+        """
+        Return name of message queue used for sending
+        info requests
+
+        Queue is a publish/subscribe queue:
+        Each message is broadcast to all readers.
+        """
+        return 'cb-info-request'
+
+    @staticmethod
+    def get_info_response_queue_name() -> str:
+        """
+        Return name of message queue used for sending
+        info response messages
+
+        Queue is a publish/subscribe queue:
+        Each message is broadcast to all readers.
+        """
+        return 'cb-info-response'
+
     @staticmethod
     def get_runner_results_root() -> str:
         """
@@ -107,13 +138,15 @@ class Defaults:
             package_changed='package source changed',
             package_build_failed='package build failed',
             package_build_succeeded='package build succeeded',
+            package_build_running='package build running',
             buildroot_setup_failed='build root setup failed',
             buildroot_setup_succeeded='build root setup succeeded',
             package_update_request='package update request scheduled',
             package_request_accepted='package request accepted',
             incompatible_build_arch='incompatible build arch',
             reset_running_build='reset running build',
-            package_not_existing='package does not exist'
+            package_not_existing='package does not exist',
+            invalid_metadata='invalid package metadata'
         )
 
     @staticmethod
@@ -127,28 +160,6 @@ class Defaults:
         """
         return f'{os.environ.get("HOME")}/cloud_builder_sources'
 
-    @staticmethod
-    def get_package_config(package_path: str, filename: str = None) -> Dict:
-        """
-        Read cloud builder meta data file for the given package
-
-        :param str package_path: path to package sources
-        :param str filename:
-            alternative meta data file name, default is cloud_builder.yml
-
-        :return: yaml dictionary data
-
-        :rtype: Dict
-        """
-        config_data: Dict[str, str] = {}
-        config_file = filename or os.path.join(
-            package_path, 'cloud_builder.yml'
-        )
-        if os.path.isfile(config_file):
-            with open(config_file, 'r') as config:
-                config_data = yaml.safe_load(config) or {}
-        return config_data
-
     @staticmethod
     def get_kafka_config() -> str:
         """
